scoretools.StaffGroup
=====================

.. abjad-lineage:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup

.. autoclass:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.descendants
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.leaves
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.lineage
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.music
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.override
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.parent
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.parentage
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.prolation
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.set
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.spanners
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.start_offset
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.storage_format
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.timespan
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.context_name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.append
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.index
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__add__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__ge__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__gt__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__iadd__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__imul__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__le__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__lt__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__radd__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__setitem__
   :noindex:
